<!DOCTYPE kpartgui >
<kpartgui version="1" name="krusaderlister" >
 <MenuBar>
  <Menu name="lister" >
   <text>Lister</text>
   <Action name="save_as" />
   <Action name="save_selected" />
   <Action name="print" />
   <Separator/>
   <Action name="search" />
   <Action name="search_next" />
   <Action name="search_prev" />
   <Action name="jump_to_position" />
   <Separator/>
   <Action name="changeremoteencoding" />
   <Action name="hex_mode" />
  </Menu>
 </MenuBar>
</kpartgui>
